/* jshint node: true */

'use strict';

import fs from 'fs';
import _ from 'lodash';
import path from 'path';
import process from 'process';
import glob from 'glob-promise';
import fixtures from '../include/fixtures.js';

/**
 * @name build_fixture_tree:
 */
let build_fixture_tree = () => {

  let fixtures_dir = path.resolve(
    __dirname, '..', 'tests', 'fixtures'
  );

  let fixtures_pattern = path.join(
    fixtures_dir, '*', '*', '*'
  );

  return glob(fixtures_pattern).then((_files) => {

    let rv = {};

    _.each(_files, (_file) => {

      let module_dir = path.dirname(_file);
      let type_dir = path.dirname(module_dir);

      let name = path.basename(_file);
      let type = path.basename(type_dir);
      let module = path.basename(module_dir);

      _.updateWith(rv, [ type, module, name ], _.constant(true));
    });

    return rv;
  });
};


/**
 * @name header:
 *   Write a descriptive comment to standard output.
 */
let header = () => {

  let s = [
    '/*', (new Date()).toString(), '*/', '\n'
  ].join(' ');

  process.stdout.write(s);
  return false;
};

/**
 * @name main:
 */
let main = () => {

  let is_first = true;

  build_fixture_tree().then((_fixture_tree) => {

    return fixtures.compile_tree(_fixture_tree);

  }).then((_fixture_tree) => {

    if (is_first) {
      is_first = header();
    }
    process.stdout.write(
      fixtures.serialize_tree(_fixture_tree)
    );

  }).catch((_e) => {

    console.error('Compilation failed: ' + _e.toString());
    process.exit(1);
  });
};

main();

