/* @flow */

'use strict';

import Base from './base';
import utils from './utils';
import _ from './utils/lodash';

/**
 * @name Exception:
 *   A base class for exception objects.
 */
var Exception = class extends Base {

  /**
   * @name constructor:
   */
  constructor (_message: ?string, _previous: any, _options: ?Object) {

    /* Must be first */
    super(_options);

    if (!_.isNil(_message) && !_.isString(_message)) {
      throw new Exception('Exception message must be a string');
    }

    if (_.isNil(_previous) || _previous === false) {
      _previous = null;
    }
    
    if (_previous && !(_previous instanceof Exception)) {
      throw new Exception('Invalid exception object');
    }

    this._message = _message;
    this._previous = _previous;

    return this;
  }

  /**
   * @name previous:
   */
  get previous (): any {

    return this._previous;
  }

  /**
   * @name message:
   */
  get message (): ?string {

    return this._message;
  }

};

/**
 * @name argument:
 *   An exception object for argument precondition violations.
 */
var Argument = class extends Exception {};

/**
 * @name range:
 *   An exception object for out-of-range values.
 */
var Range = class extends Exception {};

/**
 * @name runtime:
 *   An exception object for general runtime errors.
 */
var Runtime = class extends Exception {};

/**
 * @name reference:
 *   An exception object for invalid references to entities.
 */
var Reference = class extends Exception {};

/**
 * @name unexpected:
 *   An exception object for situations that shouldn't happen.
 */
var Unexpected = class extends Exception {};

/**
 * @name exports:
 *   Named and default exports for this module.
 */
export default {
  base: Exception,
  argument: Argument,
  range: Range, runtime: Runtime,
  reference: Reference, unexpected: Unexpected
};

export {
  Exception as base,
  Argument as argument,
  Range as range, Runtime as runtime,
  Reference as reference, Unexpected as unexpected
};

