
'use strict';

import Iterator from './base';
import _ from '../utils/lodash';
import promise from '../promise';
import exception from '../exception';

/**
 * @name Iterator.Array:
 *   A simple iterator subclass backed by an in-memory array
 *   or array-like iterable object.
 */
var iterator_array = Iterator.Array = class extends Iterator {

  /**
   * @name constructor:
   */
  constructor (_list, _options) {

    /* Must be first */
    super(_options);

    this._list = _list;
    return this.reset();
  }

  /**
   * @name reset:
   *   See superclass documentation for details.
   */
  reset () {

    this._is_filled = false;
    this._repeat = this.options.repeat;

    if (this._repeat === true) {
      this._repeat = Infinity;
    } else if (_.isNil(this._repeat) || _.isBoolean(this._repeat)) {
      this._repeat = 1;
    }

    return super.reset();
  }

  /**
   * @name populate:
   *   See superclass documentation for details.
   */
  populate (_in_reverse, _is_sequential, _is_inexact, _is_eof) {

    let key = this.key;

    /* Handle empty input */
    if (this._list.length <= 0) {
      return promise.resolve(false);
    }

    /* Enforce repetition limit */
    if (!_in_reverse && this._is_filled && this._repeat <= 0) {
      return promise.resolve(false);
    }

    this._is_filled = true;
    this._repeat += (_in_reverse ? 1 : -1);

    /* No clone */
    this.buffer = this._list;

    let p = super.populate(
      _in_reverse, _is_sequential, _is_inexact
    );

    return p.then((_is_filled) => {

      /* Refill complete:
          Now seek to `this.key` inside of the new list if necessary. */

      if (_is_filled && !_is_sequential && !_.isNil(key)) {
        if ((this.offset = this.find(key, false, _is_inexact)) === false) {
          return false;
        }
      }

      return _is_filled;
    });
  }
};

/**
 * @name exports:
 *   Named and default exports for this module.
 */
export default Iterator.Array;
export { iterator_array as array };

