/* globals emit */

'use strict';

import _ from '../../utils/lodash.js';
import links from '../transform/links.js';
import words from '../transform/words.js';
import nodes_by_tag from '../transform/nodes-by-tag.js';
import nodes_by_zone from '../transform/nodes-by-zone.js';
import nodes_by_title from '../transform/nodes-by-title.js';

/**
 * @name _rewrite_view:
 */
let _rewrite_view = (_view) => {

  let rv = {};
  let keys = { map: 0, reduce: 1 };

  for (let k in keys) {

    if (!_view[k]) {
      continue;
    }

    if (_.isString(_view[k])) {
      rv[k] = _view[k];
    } else {
      rv[k] = (
        'function (_doc) {' +
          'return (' + _view[k].toString() + ')(emit, _doc);' +
        '}'
      );
    }
  }

  return rv;
};

/**
 * @name default:
 *   Map/reduce views for PouchDB and CouchDB-compatible databases.
 */
export default {
  nodes_by_zone: _rewrite_view(nodes_by_zone),
  nodes_by_title: _rewrite_view(nodes_by_title),
  nodes_by_tag: _rewrite_view(nodes_by_tag),
  links: _rewrite_view(links),
  words: _rewrite_view(words)
};

