/* @flow */

'use strict';

import Base from '../base';
import { collate } from 'pouchdb-collate';

/**
 * @name Transform:
 */
var Transform = class extends Base {

  /**
   * @name constructor:
   */
  constructor (_transform: Object, _options: ?Object) {

    /* Must be first */
    super(_options);

    this._transform = _transform;
    this._sort = !!this.option('sort');
    this._include_docs = !!this.option('include_docs');

    this._collator = (
      this.option('collator') || { collate: collate }
    );

    return this;
  }

  /**
   * @name map:
   */
  map (_docs: Array<Object>): Array<Object> {

    let rv = [];

    for (let i = 0, len = _docs.length; i < len; ++i) {

      this._transform.map((_k, _v) => {

        if (this._include_docs) {
          _v.doc = _docs[i];
        }
        rv.push({
          id: (_v || {})._id, key: _k, value: _v
        });
      }, _docs[i]);
    }

    if (this._sort) {
      rv.sort((_l, _r) => {
        return this._collator.collate(_l.key, _r.key);
      });
    }

    return rv;
  }
};

/**
 * @name exports:
 *   Named and default exports for this module.
 */
export default Transform;
export { Transform as base };

