/* globals emit */

'use strict';

/**
 * @name map:
 *   Transform an `index` document into an ordered series of
 *   word objects, suitable for a full-text index.
 */
let map = (_result_fn, _doc) => {

  if (_doc.type !== 'index') {
    return false;
  }

  /* For each word... */
  ((_doc.data || {}).words || []).forEach((_w) => {

    /* Incoming tuple format:
        0: zone_id, 1: word, 2: offset, 3: length, 4: ordinal */

    let key = [
      _doc.zone_id, _w[0], _doc.node_id, _w[1], _w[2], _w[3]
    ];

    _result_fn(key, {
      type: _doc.type, _id: _doc._id,
      _rev: _doc._rev, title: _doc.data.title
    });
  });

  return true;
};

export { map };
export default { map: map };

