/**
 * Copyright (c) 2011 Google, Inc.
 * Copyright (c) 2013 BitPay, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import exception from '../exception'

/**
 * @name encode:
 *   Encode the buffer specified by `_source` using `_alphabet`.
 *   Returns a base N string, where N is the length of `_alphabet`.
 */
let encode = (_source, _alphabet) => {

  let rv = '';
  let digits = [ 0 ];
  let base = (_alphabet || '').length;

  if (base === 0) {
    throw new exception.argument('Alphabet must be provided');
  }

  if (_source.length === 0) {
    return '';
  }

  /* Encode to string */
  for (var i = 0; i < _source.length; ++i) {

    for (var j = 0, carry = _source[i]; j < digits.length; ++j) {
      carry += digits[j] << 8;
      digits[j] = carry % base;
      carry = (carry / base) | 0;
    }

    while (carry > 0) {
      digits.push(carry % base);
      carry = (carry / base) | 0;
    }
  }

  /* Deal with leading zeros */
  for (var k = 0; _source[k] === 0 && k < _source.length - 1; ++k) {
    rv += _alphabet[0];
  }

  /* Convert digits to a string */
  for (var q = digits.length - 1; q >= 0; --q) {
    rv += _alphabet[digits[q]];
  }

  return rv;
}

export default {
  encode: encode
};

