
'use strict';

import _ from '../utils/lodash';
import exception from '../exception';
import unicode_categories from './unicode/categories';

/**
 * @name regex_for_category:
 *   Generate an ES5 regular expression fragment for the Unicode
 *   category `_category_name`. Returns a string. Throws if an
 *   invalid or unsupported category is specified.
 */
let regex_for_category = (_category_name, _include_astral, _filter_fn) => {

  let rv = [];
  let category = unicode_categories[_category_name];

  if (!category) {
    throw new exception.argument('Invalid or unsupported category name');
  }

  /* Apply filter */
  if (!_.isNil(_filter_fn)) {
    for (var k in category) {
      category[k] = _filter_fn.call(unicode_categories, category[k]);
    }
  }

  /* Astral plane */
  if (_include_astral && category.astral) {
    rv.push(`(?:${category.astral})`);
  }

  /* Basic multilingual plane */
  rv.push(`[${category.bmp}]`);

  return `(?:${rv.join('|')})`;
};

/**
 * @name default:
 */
export default {
  regex_for_category: regex_for_category
};

