
'use strict';

import Base from './base';
import _ from './utils/lodash';
import exception from './exception';

/**
 * @name View:
 *   A simple database view compiler.
 */
var View = class extends Base {

  /**
   * @name constructor:
   */
  constructor (_object, _options) {

    /* Must be first */
    super(_options);

    this.clear();

    if (!_.isNil(_object)) {
      this.object = _object;
    }

    return this;
  }

  /**
   * @name set object:
   */
  set object (_object) {

    if (!_.isPlainObject(_object)) {
      throw new exception.argument('View must be a plain object');
    }

    this._object = _object;
  }

  /**
   * @name get object:
   */
  get object () {

    return this._object;
  }

  /**
   * @name get result:
   */
  get result () {

    return this._result;
  }

  /**
   * @name clear:
   */
  clear () {

    this._result = this._object = null;
    return this;
  }

  /**
   * @name build:
   */
  build (_object) {

    if (!_.isNil(_object)) {
      this.object = _object;
    }

    return this;
  }
};

/**
 * @name View.PouchDB:
 *  A PouchDB-specific view compiler.
 */
var view_pouchdb = View.PouchDB = class extends View {

  /**
   * @name build:
   */
  build (_object) {

    /* Must be first */
    super.build(_object);

    let rv = {};
    let view = this.object;

    _.each({ map: 0, reduce: 1 }, (_n, _type) => {
      rv[_type] = (
        _.isFunction(view[_type]) ?
          this._postprocess(view[_type].toString()) : view[_type]
      );
    });

    this._result = rv;
    return this;
  }

  /**
   * @name _postprocess:
   *   Perform simple string-based code rewiting, aimed
   *   at removing unnecessary whitespace and/or garbage.
   */
  _postprocess (_string) {

    return _string.replace(/\s+/g, ' ');
  }
};

/**
 * @name exports:
 *   Named and default exports for this module.
 */
export {
  View as base,
  view_pouchdb as pouchdb
};

export default {
  base: View,
  pouchdb: View.PouchDB
};

