
'use strict';

import _ from '../unit/utils/lodash';
import promise from '../../src/promise';
import indexer from '../../src/indexer';
import exception from '../../src/exception';
import fixtures from '../../output/fixtures/all';

/**
 * @name store_fixture:
 *   Create, store, and index a test document using a test
 *   fixture as content. Returns a promise from `schema.store`.
 */
let store_fixture = (_schema, _fixture_name, _fixtures) => {

  if (!_fixtures) {
    _fixtures = fixtures.unit.text;
  }

  let i = new indexer.text();
  let text = _fixtures[_fixture_name];

  let tags = [
    `${_fixture_name} fixture`, 'test'
  ];

  let index_options = {
    tags: tags
  };

  let index_doc = {
    type: 'index',
    data: i.build(text, index_options).result
  };

  let doc = {
    type: 'node', zone_id: 0,
    content: text, title: _fixture_name, tags: tags
  };

  _.assignIn(index_doc, {
    zone_id: 0
  });

  _.assignIn(index_doc.data, {
    title: _fixture_name
  });

  let path_fn = (_is_backward) => {
    return (_is_backward ? 'node_id' : 'index_id');
  };

  return _schema.store(doc).then((_doc) => {
    return _schema.store_linked(_doc, index_doc, path_fn);
  });
};

/**
 * store_fixtures:
 *   Persist a set of fixtures to the database as indexed documents.
 */
let store_fixtures = (_schema, _fixture_names, _fixtures) => {

  return promise.all(_.map(
    _fixture_names,
      _.partial(store_fixture, _schema, _._, _fixtures)
  ));
};

/**
 * remove_fixtures:
 *   Remove a set of documents added via `store_fixtures`.
 */
let remove_fixtures = (_schema, _results) => {

  if (!_.isArray(_results)) {
    _results = [ _results ];
  }

  return promise.all(
    _.flatMap(_results, (_r) => {
      return [ _schema.remove(_r.doc), _schema.remove(_r.linked_doc) ];
    })
  );
};

/**
 * @name compare_word_index_key:
 *   Compare an iterator's current key to an expected key,
 *   but exclude UUIDs and other similarly ephemeral values.
 */
let compare_word_index_key = (_key, _expect) => {

  _expect[0].should.equal(_key[0]);
  _expect[1].should.equal(_key[1]);
  _expect[2].should.equal(_key[3]);
};

/**
 * all:
 *   Return all available fixture data.
 */
let all = () => {

  return fixtures;
};

/**
 * @name exports:
 *   Named and default exports for this module.
 */
export {
  all,
  store_fixture,
  store_fixtures,
  remove_fixtures,
  compare_word_index_key
};

export default {
  all: all,
  store_fixture: store_fixture,
  store_fixtures: store_fixtures,
  remove_fixtures: remove_fixtures,
  compare_word_index_key: compare_word_index_key
};

