/* @flow */
/* istanbul ignore file */

'use strict';

/**
 * @name base_directory:
 *   Return an appropriate project base directory or base
 *   URL for the current testing environment. Where required,
 *   a fully-qualified absolute path or URL will be returned.
 */
let base_directory = () => {

  /* Node */
  if (typeof process === 'object') {
    return process.cwd();
  }

  /* Non-browser: best guess */
  if (typeof window !== 'object') {
    return '';
  }

  /* Browser: via Karma */
  if (typeof window.__karma__ !== 'undefined') {
    return `${window.location.href}/../base`;
  }

  /* PhantomJS test environment */
  if (window.phantomjs_info) {
    if (window.phantomjs_info.userAgent === window.navigator.userAgent) {
      return `file://${window.phantomjs_info.workingDirectory}`;
    }
  }

  /* Browser: direct */
  return `${window.location.href}/../../..`;
};

/**
 * @name exports:
 *   Named and default exports for this module.
 */
export {
  base_directory
};

export default {
  base_directory: base_directory
};

