
'use strict';

import chai from 'chai';
import base from '../../src/base';

/**
 * @name base:
 *   Unit tests for the universal subclass module.
 */
describe('base', () => {

  let should = chai.should();

  /**
   * @name can be constructed:
   */
  it('can be constructed', () => {

    (() => { new base(); }).should.not.throw();
    (() => { new base({}); }).should.not.throw();
  });

  /**
   * @name retrieves a constructor-set option:
   */
  it('retrieves a constructor-set option', () => {

    let b = new base({ bar: 'baz', quux: 'zzyz' });

    b.option('bar').should.equal('baz');
    b.options.quux.should.equal('zzyz');
  });

  /**
   * @name changes options successfully:
   */
  it('changes options successfully', () => {

    let b = new base({ bar: 'baz', quux: 'zzyz' });

    b.option('bar').should.equal('baz');

    b.option('bar', null).should.equal('baz');
    should.not.exist(b.option('bar', false));

    b.option('bar', {}).should.equal(false);
    b.option('bar', []).should.be.an.object;
    b.option('bar', 'string').should.be.an.array;
    b.option('bar').should.equal('string');

    b.option('bar', undefined).should.equal('string');
    b.option('bar').should.equal('string');
  });

  /**
   * @name clones options:
   */
  it('clones options', () => {

    let o = { foo: 'baz' };
    let b = new base(o);

    b.option('foo').should.equal('baz');
    o.foo = 'bar';
    b.option('foo').should.equal('baz');
  });

  /**
   * @name does not deep-clone options:
   */
  it('does not deep-clone options', () => {

    let o = { foo: { bar: 'baz' } };
    let b = new base(o);

    b.option('foo').bar.should.equal('baz');
    o.foo.bar = 'quux';
    b.option('foo').bar.should.equal('quux');
  });

  /**
   * @name overwrites options:
   */
  it('overwrites options', () => {

    let b = new base({ foo: 'bar' });

    b.options = { foo: 'baz' };
    b.option('foo').should.equal('baz');

    b.options = {};
    should.not.exist(b.option('quux'));
    should.not.exist(b.option('quux', 'zzyz'));
    b.option('quux').should.equal('zzyz');
  });

});

