
'use strict';

import chai from 'chai';
import exception from '../../src/exception';

/**
 * @name exception:
 *   Unit tests for the exception module.
 */
describe('exception', () => {

  let should = chai.should();

  /**
   * @name can be constructed:
   */
  it('can be constructed', () => {

    (() => { new exception.base('Hello'); }).should.not.throw();
    (() => { new exception.argument('Hi'); }).should.not.throw();
  });

  /**
   * @name treats message as optional:
   */
  it('treats message as optional', () => {

    (() => { new exception.range(); }).should.not.throw();
  });

  /**
   * @name rejects invalid messages:
   */
  it('rejects invalid messages', () => {

    (() => { new exception.range(1); }).should.throw();
    (() => { new exception.range(true); }).should.throw();
    (() => { new exception.range(false); }).should.throw();
    (() => { new exception.range([]); }).should.throw();
    (() => { new exception.range({}); }).should.throw();
    (() => { new exception.range(/foo/); }).should.throw();
  });

  /**
   * @name checks the type of the previous exception:
   */
  it('checks the type of the previous exception', () => {

    (() => { new exception.runtime('Hi', {}); }).should.throw(exception);
  });

  /**
   * @name accepts a parent object:
   */
  it('accepts a parent object', () => {

    (() => {
      let e1 = new exception.range('World');
      let e2 = new exception.base('Hello', e1);
      e2.previous.should.equal(e1);
      e2.previous.options.should.be.an.object;
      e2.previous.message.should.equal('World');
    }).should.not.throw();
  });

  /**
   * @name accepts and returns an options object:
   */
  it('accepts and returns an options object', () => {

    (() => {
      let e = new exception.range('Hello', null, { nihilism: true });
      e.message.should.equal('Hello');
      e.options.nihilism.should.be.true;
      should.not.exist(e.previous);
    }).should.not.throw();
    
    (() => {
      let e = new exception.range('Hi', false, { memes: 'dank' });
      e.message.should.equal('Hi');
      e.options.memes.should.equal('dank');
      should.not.exist(e.previous);
    }).should.not.throw();
  });
});

