
'use strict';

import chai from 'chai';
import _ from './utils/lodash';
import promise from '../../src/promise';
import promises from 'chai-as-promised';
import exception from '../../src/exception';

/**
 * @name promise:
 *   Unit tests for the promise utilities library.
 */
describe('promise', () => {

  let should = chai.should();
  chai.use(promises);

  /**
   * @name runs a simple loop properly:
   */
  it('runs a simple loop properly', () => {

    let i = 0;
    const iterations = 10;

    return promise.while(() => (i < iterations), () => {
      return new promise.base((_resolve_fn, _reject_fn) => {
        _.defer(() => { i++; _resolve_fn(); });
      });
    }).then(() => {
      i.should.equal(iterations);
    });
  });

  /**
   * @name handles rejection properly:
   */
  it('handles rejection properly', () => {

    return promise.while(_.identity(true), () => {
      return new promise.base((_resolve_fn, _reject_fn) => {
        _.defer(() => {
          return _reject_fn(new exception.unexpected());
        });
      });
    }).catch((_e) => {
      should.exist(_e); throw _e;
    }).should.eventually.be.rejected;
  });
});

