
'use strict';

import chai from 'chai';
import _ from './utils/lodash';
import schema from '../../src/schema';
import promise from '../../src/promise';
import promises from 'chai-as-promised';
import exception from '../../src/exception';

/**
 * @name schema:
 *   Unit tests for the schema module.
 */
describe('schema', () => {

  let should = chai.should();
  chai.use(promises);

  let b = new schema.base();

  /**
   * @name base:
   *   Tests related to base class functionality.
   */
  describe('base', () => {

    /**
     * @name deploys:
     */
    it('deploys', () => {
      b.deploy().should.eventually.be.rejected;
    });

    /**
     * @name gets:
     */
    it('gets', () => {
      b.get('t').should.eventually.be.rejected;
    });

    /**
     * @name stores:
     */
    it('stores', () => {
      b.store({}).should.eventually.be.rejected;
    });

    /**
     * @name removes:
     */
    it('removes', () => {
      b.remove({}).should.eventually.be.rejected;
    });

    /**
     * @name compacts:
     */
    it('compacts', () => {
      b.compact().should.eventually.be.fulfilled;
    });

    /**
     * @name validates retry count in remove_forced:
     */
    it('validates retry count in remove_forced', () => {

      (() => {
        b.remove_forced({}, 'memes');
      }).should.throw(exception.runtime);

      b.remove_forced({}, () => 'memes')
        .should.eventually.be.rejected;

      b.remove_forced({}, () => promise.resolve('memes'))
        .should.eventually.be.rejected;
    });

    /**
     * @name rejects invalid update path in store_linked:
     */
    it('rejects invalid update path in store_linked', () => {

      return b.store_linked({}, {}, 1).should.eventually.be.rejected;
    });

    /**
     * @name has an all method:
     */
    it('has an all method', () => {
      b.all().should.eventually.be.rejected;
    });

    /**
     * @name has a view method:
     */
    it('has a view method', () => {
      b.view('memes').should.eventually.be.rejected;
    });

    /**
     * @name can be undeployed:
     */
    it('can be undeployed', () => {
      return b.undeploy();
    });

    /**
     * @name can be destroyed:
     */
    it('can be destroyed', () => {
      return b.destroy();
    });

    /**
     * @name returns current version:
     */
    it('returns current version', () => {
      b.version().should.eventually.equal(-1);
    });

    /**
     * @name returns latest version:
     */
    it('returns latest version', () => {
      b.latest_version.should.equal(-1);
    });

    /**
     * @name collates:
     */
    it('collates', () => {

      b.collate(' ', ' ').should.equal(0);
      b.collate('a', 'z').should.equal(-1);
      b.collate('zz', 'zy').should.equal(1);
      b.collate('mémé', 'meme').should.equal(1);

      b.collate('Č', 'D').should.equal(1);
      b.collate('Č', 'Ć').should.equal(1);
      b.collate('Ł', 'Z').should.equal(1);
    });

    /**
     * @name cleanup:
     */
    it('cleanup', () => {
      return b.cleanup().should.eventually.be.fulfilled;
    });
  });
});

