
'use strict';

import chai from 'chai';
import _ from '../utils/lodash';
import splitter from '../../../src/splitter';
import exception from '../../../src/exception';
import fixtures from '../../../output/fixtures/all';

/**
 * @name html:
 *   Unit tests for the Unicode HTML markup splitter.
 */
describe('text', () => {

  let should = chai.should();
  let s = new splitter.html();

  /**
   * @name split:
   */
  describe('split', () => {

    /**
     * @name splits simple HTML:
     */
    it('splits simple HTML', () => {

      let r = s.reset().split(
        '<a>Hello <i>cruel</i> HTML world</a>'
      ).result;

      r.should.deep.equal([
        [ 'Hello', 3, 5, 0 ], [ 'cruel', 12, 5, 1 ],
        [ 'HTML', 22, 4, 2 ], [ 'world', 27, 5, 3 ]
      ]);
    });

    /**
     * @name splits with HTML entities:
     */
    it('splits with HTML entities', () => {

      let r = s.reset().split(
        '<a>Hello &amp; goodbye &#33;</a>'
      ).result;

      r.should.deep.equal([
        [ 'Hello', 3, 5, 0 ], [ 'goodbye', 15, 7, 1 ]
      ]);
    });

    /**
     * @name forms words from HTML entities:
     */
    it('forms words from HTML entities', () => {

      let r = s.reset().split(
        '<a>&#72;&#101;&#108;&#108;&#111;&#33;</a>'
      ).result;

      r.should.deep.equal([
        [ 'Hello', 3, 29, 0 ]
      ]);

      r = s.reset().split(
        '&#72;&#105;&#32;&#87;&#111;&#114;&#108;&#100;'
      ).result;

      r.should.deep.equal([
        [ 'Hi', 0, 11, 0 ], [ 'World', 16, 29, 1 ]
      ]);
    });

  });
});

