
'use strict';

import chai from 'chai';
import exception from '../../../src/exception';
import basex from '../../../src/utils/basex-tiny';

/**
 * @name base:
 *   Unit tests for the embedded basex module.
 */
describe('basex', () => {

  let should = chai.should();

  /**
   * @name encodes empty buffers:
   */
  it('encodes empty buffers', () => {

    basex.encode(new Uint8Array(0), 'ABC').should.equal('');
  });

  /**
   * @name rejects empty alphabets:
   */
  it('rejects empty alphabets', () => {

    let a0 = new Uint8Array(0);
    let a1 = new Uint8Array(1); a1[0] = 1;

    (() => basex.encode(a0)).should.throw(exception.argument);
    (() => basex.encode(a1)).should.throw(exception.argument);
    (() => basex.encode(a0, '')).should.throw(exception.argument);
    (() => basex.encode(a1, '')).should.throw(exception.argument);
  });

  /**
   * @name handles leading zeroes:
   */
  it('handles leading zeroes', () => {

    let a = new Uint8Array(2);
    a[0] = 0; a[1] = 3;

    basex.encode(a, '01').should.equal('011');
  });
});

