
'use strict';

import chai from 'chai';
import view from '../../src/view';
import exception from '../../src/exception';

/**
 * @name view:
 *   Unit tests for the view wrapper.
 */
describe('view', () => {

  let should = chai.should();
  let v = new view.pouchdb();

  it('rewrites a simple view properly', () => {

    let simple_view = {
      reduce: '_count',
      map: (_doc) => { emit(_doc.id, null); }
    };

    let o = v.build(simple_view).object;

    o.should.be.an.object;
    o.map.should.be.a.string;
    o.reduce.should.be.a.string;
  });

  it('leaves an already-rewritten view unmodified', () => {

    let view = {
      reduce: '_count',
      extra_property: true,
      map: 'function (_doc) { emit(doc._id, null); }'
    };

    let o = v.build(view).object;

    o.should.be.an.object;
    o.map.should.deep.equal(view.map);
    o.reduce.should.deep.equal(view.reduce);
    o.extra_property.should.deep.equal(view.extra_property);
  });

  it('returns valid options', () => {

    v.options.should.be.an.object;
  });

  it('rejects non-objects', () => {

    (() => { v.object = 1; }).should.throw(exception.argument);
    (() => { v.object = []; }).should.throw(exception.argument);
    (() => { v.object = new Date(); }).should.throw(exception.argument);
  });
});

